==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/datagen/EntityLootTableProvider.java <==
package cc.thonly.reverie_dreams.datagen;

import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import cc.thonly.reverie_dreams.registry.content.item.RDFoodItems;
import cc.thonly.reverie_dreams.registry.content.item.RDIngredientItems;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricEntityLootTableProvider;
import net.minecraft.class_141;
import net.minecraft.class_1802;
import net.minecraft.class_219;
import net.minecraft.class_44;
import net.minecraft.class_52;
import net.minecraft.class_55;
import net.minecraft.class_5662;
import net.minecraft.class_7225;
import net.minecraft.class_77;
import java.util.concurrent.CompletableFuture;

public class EntityLootTableProvider extends FabricEntityLootTableProvider {
    public EntityLootTableProvider(FabricDataOutput dataOutput, CompletableFuture<class_7225.class_7874> registryLookup) {
        super(dataOutput, registryLookup);
    }

    @Override
    public void method_10400() {
        this.method_46029(RDEntityTypes.WILD_PIG,
                new class_52.class_53()
                        .method_336(new class_55.class_56()
                                .method_352(class_5662.method_32462(1.0f, 3.0f))
                                .method_351(class_77.method_411(RDIngredientItems.WILD_BOAR_MEAT))
                        )
        );
        this.method_46029(RDEntityTypes.MOON_RABBIT_ENTITY_TYPE,
                new class_52.class_53()
                        .method_336(new class_55.class_56()
                                .method_352(class_44.method_32448(1.0f))
                                .method_351(class_77.method_411(class_1802.field_8504))
                        )
                        .method_336(new class_55.class_56()
                                .method_352(class_44.method_32448(0.8f))
                                .method_351(class_77.method_411(class_1802.field_8073))
                        )
                        .method_336(class_55.method_347()
                                .method_352(class_44.method_32448(1))
                                .method_356(class_219.method_932(0.4f))
                                .method_351(class_77.method_411(class_1802.field_8397)
                                        .method_438(class_141.method_621(class_5662.method_32462(1f, 3f)))
                                )
                        ).method_336(class_55.method_347()
                                .method_352(class_44.method_32448(1))
                                .method_356(class_219.method_932(0.1f))
                                .method_351(class_77.method_411(RDFoodItems.MOONLIGHT_DUMPLINGS)
                                        .method_438(class_141.method_621(class_5662.method_32462(1f, 3f)))
                                )
                        )
        );
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/datagen/EntityLootTableProvider.java <==
package cc.thonly.reverie_dreams.datagen;

import cc.thonly.reverie_dreams.registry.content.entity.RDEntityTypes;
import cc.thonly.reverie_dreams.registry.content.item.RDFoodItems;
import cc.thonly.reverie_dreams.registry.content.item.RDIngredientItems;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricEntityLootTableProvider;
import net.minecraft.class_141;
import net.minecraft.class_1802;
import net.minecraft.class_219;
import net.minecraft.class_44;
import net.minecraft.class_52;
import net.minecraft.class_55;
import net.minecraft.class_5662;
import net.minecraft.class_7225;
import net.minecraft.class_77;
import java.util.concurrent.CompletableFuture;

public class EntityLootTableProvider extends FabricEntityLootTableProvider {
    public EntityLootTableProvider(FabricDataOutput dataOutput, CompletableFuture<class_7225.class_7874> registryLookup) {
        super(dataOutput, registryLookup);
    }

    @Override
    public void method_10400() {
        this.method_46029(RDEntityTypes.WILD_PIG,
                new class_52.class_53()
                        .method_336(new class_55.class_56()
                                .method_352(class_5662.method_32462(1.0f, 3.0f))
                                .method_351(class_77.method_411(RDIngredientItems.WILD_BOAR_MEAT))
                        )
        );
        this.method_46029(RDEntityTypes.MOON_RABBIT,
                new class_52.class_53()
                        .method_336(new class_55.class_56()
                                .method_352(class_44.method_32448(1.0f))
                                .method_351(class_77.method_411(class_1802.field_8504))
                        )
                        .method_336(new class_55.class_56()
                                .method_352(class_44.method_32448(0.8f))
                                .method_351(class_77.method_411(class_1802.field_8073))
                        )
                        .method_336(class_55.method_347()
                                .method_352(class_44.method_32448(1))
                                .method_356(class_219.method_932(0.4f))
                                .method_351(class_77.method_411(class_1802.field_8397)
                                        .method_438(class_141.method_621(class_5662.method_32462(1f, 3f)))
                                )
                        ).method_336(class_55.method_347()
                                .method_352(class_44.method_32448(1))
                                .method_356(class_219.method_932(0.1f))
                                .method_351(class_77.method_411(RDFoodItems.MOONLIGHT_DUMPLINGS)
                                        .method_438(class_141.method_621(class_5662.method_32462(1f, 3f)))
                                )
                        )
        );
    }
}
